=======
History
=======


0.1.2 (2020-09-02)
------------------

* Update README and documentation.
* Traslate the documentation to spanish.
* Fix another deploy issue.

0.1.1 (2020-08-31)
------------------

* Fix deploy issue.


0.1.0 (2020-08-30)
------------------

* First release on PyPI.
* Electoral roll feature.